@@ -17,7 +17,11 @@ import click
 import requests
 
 from newrelic_lambda_cli.cliutils import failure, success
-from newrelic_lambda_cli.types import IntegrationInstall, LayerInstall
+from newrelic_lambda_cli.types import (
+    IntegrationInstall,
+    IntegrationUpdate,
+    LayerInstall,
+)
 from newrelic_lambda_cli.utils import parse_arn
 
 __cached_license_key = None
@@ -156,10 +160,16 @@ class NewRelicGQL(object):
         try:
             return res["cloudLinkAccount"]["linkedAccounts"][0]
         except (IndexError, KeyError):
-            if "errors" in res:
+            if "errors" in res["cloudLinkAccount"]:
                 failure(
                     "Error while linking account with New Relic:\n%s"
-                    % "\n".join([e["message"] for e in res["errors"] if "message" in e])
+                    % "\n".join(
+                        [
+                            e["message"]
+                            for e in res["cloudLinkAccount"]["errors"]
+                            if "message" in e
+                        ]
+                    )
                 )
             return None
 
@@ -323,7 +333,7 @@ class NewRelicGQL(object):
 
 
 def validate_gql_credentials(input):
-    assert isinstance(input, (IntegrationInstall, LayerInstall))
+    assert isinstance(input, (IntegrationInstall, IntegrationUpdate, LayerInstall))
 
     try:
         return NewRelicGQL(input.nr_account_id, input.nr_api_key, input.nr_region)
